@@ -8,6 +8,23 @@ from easypubsub.logging import getLogger
 
 
 class Subscriber:
+    """The EasyPubSub Subscriber provides an interface to subscribe to one or more topics.
+
+    Attributes:
+        name (str): The name of the subscriber. This is used for logging purposes.
+        proxy_subscribers_address (str): The address that the subscriber will use to
+            connect to the :obj:`~easypubsub.proxy.Proxy`.
+        topics (str | List[str]): The topics to subscribe to. If not specified, the subscriber
+            will subscribe to all topics. If specified, it can be a string or a list of strings.
+        receive_timeout (float): The timeout for receiving messages in the :meth:`receive` method.
+
+    Example:
+        >>> from easypubsub.subscriber import Subscriber
+        >>> subscriber = Subscriber("my_subscriber", "tcp://127.0.0.1:5556")
+        >>> subscriber.receive()
+        [("my_publisher", "Hello world!"), ("my_publisher.my_topic", "Hello again, world.")]
+    """
+
     def __init__(
         self,
         name: str,
@@ -29,12 +46,12 @@ class Subscriber:
 
         self._logger = getLogger(f"EasyPubSub.Subscriber({name})")
 
-        self.connect()
+        self._connect()
 
     def __del__(self) -> None:
         self.poller.unregister(self.socket)
 
-    def connect(self) -> None:
+    def _connect(self) -> None:
         self.ctx = zmq.Context.instance()
         self.socket = self.ctx.socket(zmq.SUB)
         self._logger.info(f"Connecting to {self.subscribers_address}.")
@@ -54,6 +71,15 @@ class Subscriber:
         time.sleep(1)
 
     def receive(self) -> List[Tuple[str, Any]]:
+        """Receive one or more messages from the subscriptions.
+
+        Returns:
+            List[Tuple[str, Any]]: A list of tuples, each containing the topic and the message.
+
+        Example:
+            >>> subscriber.receive()
+            [("my_publisher", "Hello world!"), ("my_publisher.my_topic", "Hello again, world.")]
+        """
         messages: List[Any] = []
         messages_available = True
         while messages_available:
